BatchBytesResult class

Result of a batch operation on in-memory bytes.

Constructors

BatchBytesResult({required List<Uint8List> results, required int failures, required List<(int, String)> errors})
const

Properties

errors List<(int, String)>
Indices that failed (0-based), paired with error messages.
final
failures int
Number of files that failed.
final
hashCode int
The hash code for this object.
no setteroverride
results List<Uint8List>
Successfully processed byte arrays, in the same order as input.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override