BatchResult class
Result of a batch operation on file paths.
Constructors
Properties
-
errors
→ List<
(String, String)> -
Paths that failed, paired with error messages.
final
- failures → int
-
Number of files that failed.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successes → int
-
Number of files successfully processed.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override