HaudiotaggerError class sealed
- Implemented types
- Available extensions
- Annotations
-
- @freezed
Constructors
- HaudiotaggerError.invalidPath()
-
constfactory
- HaudiotaggerError.noTags()
-
constfactory
- HaudiotaggerError.openFile({required String message})
-
constfactory
- HaudiotaggerError.write({required String message})
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> ({required TResult invalidPath(HaudiotaggerError_InvalidPath value), required TResult noTags(HaudiotaggerError_NoTags value), required TResult openFile(HaudiotaggerError_OpenFile value), required TResult write(HaudiotaggerError_Write value)}) → TResult -
Available on HaudiotaggerError, provided by the HaudiotaggerErrorPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> ({TResult? invalidPath(HaudiotaggerError_InvalidPath value)?, TResult? noTags(HaudiotaggerError_NoTags value)?, TResult? openFile(HaudiotaggerError_OpenFile value)?, TResult? write(HaudiotaggerError_Write value)?}) → TResult? -
Available on HaudiotaggerError, provided by the HaudiotaggerErrorPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({TResult invalidPath(HaudiotaggerError_InvalidPath value)?, TResult noTags(HaudiotaggerError_NoTags value)?, TResult openFile(HaudiotaggerError_OpenFile value)?, TResult write(HaudiotaggerError_Write value)?, required TResult orElse()}) → TResult -
Available on HaudiotaggerError, provided by the HaudiotaggerErrorPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({TResult invalidPath()?, TResult noTags()?, TResult openFile(String message)?, TResult write(String message)?, required TResult orElse()}) → TResult -
Available on HaudiotaggerError, provided by the HaudiotaggerErrorPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> ({required TResult invalidPath(), required TResult noTags(), required TResult openFile(String message), required TResult write(String message)}) → TResult -
Available on HaudiotaggerError, provided by the HaudiotaggerErrorPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> ({TResult? invalidPath()?, TResult? noTags()?, TResult? openFile(String message)?, TResult? write(String message)?}) → TResult? -
Available on HaudiotaggerError, provided by the HaudiotaggerErrorPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited