Id3v2Version enum

Represents the ID3v2 version to use when writing.

Inheritance
Available extensions

Values

v2 → const Id3v2Version

ID3v2.2 (3-character frame IDs, limited features)

v3 → const Id3v2Version

ID3v2.3 (widely supported, recommended for compatibility)

v4 → const Id3v2Version

ID3v2.4 (latest spec, but less software support)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Id3v2Version>
A constant List of the values in this enum, in order of their declaration.