Tag class
Represents the metadata of the file.
- Available extensions
Constructors
-
Tag({String? title, String? trackArtist, String? album, String? albumArtist, int? year, String? genre, int? trackNumber, int? trackTotal, int? discNumber, int? discTotal, String? lyrics, String? comment, int? duration, required List<
Picture> pictures, double? bpm, String? replayGainTrackGain, String? replayGainTrackPeak, String? replayGainAlbumGain, String? replayGainAlbumPeak}) -
const
Properties
- album → String?
-
The album the song is from.
final
- albumArtist → String?
-
The artist of the album.
final
- bpm → double?
-
Beats per minute.
final
- comment → String?
-
A comment about the song.
final
- discNumber → int?
-
The position of the disc in a list.
final
- discTotal → int?
-
The total amount of discs in a list.
final
- duration → int?
-
The duration of the song. Setting this field
when writing will do nothing.
final
- genre → String?
-
The genre of the song.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- lyrics → String?
-
The lyrics of the song.
final
-
pictures
→ List<
Picture> -
All the pictures of the song.
final
- replayGainAlbumGain → String?
-
ReplayGain album gain in dB.
final
- replayGainAlbumPeak → String?
-
ReplayGain album peak.
final
- replayGainTrackGain → String?
-
ReplayGain track gain in dB (e.g. "-6.43").
final
- replayGainTrackPeak → String?
-
ReplayGain track peak (e.g. "0.981201").
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
The title of the song.
final
- trackArtist → String?
-
The artist of the song.
final
- trackNumber → int?
-
The position of the song in a list.
final
- trackTotal → int?
-
The total amount of songs in a list.
final
- year → int?
-
The year that this song was made.
final
Methods
-
copyWith(
{String? title, String? trackArtist, String? album, String? albumArtist, int? year, String? genre, int? trackNumber, int? trackTotal, int? discNumber, int? discTotal, String? lyrics, String? comment, int? duration, List< Picture> ? pictures, double? bpm}) → Tag -
Available on Tag, provided by the TagCopyWith extension
-
isEmpty(
) → Future< bool> -
Returns
trueif the tag has no data. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override