TagField enum
A specific tag field that can be individually removed.
Values
- title → const TagField
-
The title of the song.
- artist → const TagField
-
The artist of the song.
- album → const TagField
-
The album the song is from.
- albumArtist → const TagField
-
The artist of the album.
- year → const TagField
-
The year the song was made.
- genre → const TagField
-
The genre of the song.
- trackNumber → const TagField
-
The position of the song in a list.
- trackTotal → const TagField
-
The total amount of songs in a list.
- discNumber → const TagField
-
The position of the disc in a list.
- discTotal → const TagField
-
The total amount of discs in a list.
- lyrics → const TagField
-
The lyrics of the song.
- comment → const TagField
-
A comment about the song.
- bpm → const TagField
-
Beats per minute.
- pictures → const TagField
-
All embedded pictures.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited